@@ -1,11 +1,15 @@
 /**
- * Logback: the generic, reliable, fast and flexible logging framework.
- * 
- * Copyright (C) 2000-2008, QOS.ch
- * 
- * This library is free software, you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation.
+ * Logback: the reliable, generic, fast and flexible logging framework.
+ * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ *
+ * This program and the accompanying materials are dual-licensed under
+ * either the terms of the Eclipse Public License v1.0 as published by
+ * the Eclipse Foundation
+ *
+ *   or (per the licensee's choosing)
+ *
+ * under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation.
  */
 package ch.qos.logback.access.joran.action;
 
@@ -13,6 +17,7 @@ import org.xml.sax.Attributes;
 
 import ch.qos.logback.core.joran.action.Action;
 import ch.qos.logback.core.joran.spi.InterpretationContext;
+import ch.qos.logback.core.util.ContextUtil;
 import ch.qos.logback.core.util.StatusPrinter;
 
 
@@ -32,6 +37,8 @@ public class ConfigurationAction extends Action {
       debugMode = true;
     }
 
+    new ContextUtil(context).addHostNameAsProperty();
+
     // the context is appender attachable, so it is pushed on top of the stack
     ec.pushObject(getContext());
   }
