@@ -1,3 +1,16 @@
+/**
+ * Logback: the reliable, generic, fast and flexible logging framework.
+ * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ *
+ * This program and the accompanying materials are dual-licensed under
+ * either the terms of the Eclipse Public License v1.0 as published by
+ * the Eclipse Foundation
+ *
+ *   or (per the licensee's choosing)
+ *
+ * under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation.
+ */
 package ch.qos.logback.access.servlet;
 
 import javax.servlet.http.HttpServletRequest;
@@ -8,7 +21,7 @@ import ch.qos.logback.access.AccessConstants;
 public class Util {
 
   public static boolean isFormUrlEncoded(HttpServletRequest request) {
-    if ("POST".equals(request.getMethod())
+    if ("POST".equalsIgnoreCase(request.getMethod())
         && AccessConstants.X_WWW_FORM_URLECODED.equals(request.getContentType())) {
       return true;
     } else {
