@@ -1,11 +1,15 @@
 /**
- * Logback: the generic, reliable, fast and flexible logging framework.
- * 
- * Copyright (C) 2000-2008, QOS.ch
- * 
- * This library is free software, you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation.
+ * Logback: the reliable, generic, fast and flexible logging framework.
+ * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ *
+ * This program and the accompanying materials are dual-licensed under
+ * either the terms of the Eclipse Public License v1.0 as published by
+ * the Eclipse Foundation
+ *
+ *   or (per the licensee's choosing)
+ *
+ * under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation.
  */
 package ch.qos.logback.classic.turbo;
 
@@ -14,6 +18,8 @@ import java.util.Map;
 
 class LRUMessageCache extends LinkedHashMap<String, Integer> {
 
+  // LinkedHashMap permits null elements to be inserted
+  
   private static final long serialVersionUID = 1L;
   
   final int cacheSize;
@@ -26,7 +32,12 @@ class LRUMessageCache extends LinkedHashMap<String, Integer> {
     this.cacheSize = cacheSize;
   }
   
-  int getMessageCount(String msg) {
+  int getMessageCountAndThenIncrement(String msg) {
+    // don't insert null elements
+    if(msg == null) {
+      return 0;
+    }
+    
     Integer i = super.get(msg);
     if(i == null) {
       i = 0;
