@@ -13,11 +13,17 @@
  */
 package ch.qos.logback.classic;
 
-public class ClassicTestConstants {
+import ch.qos.logback.core.util.CoreTestConstants;
 
-  final static public String ISO_REGEX =  "\\d{4}-\\d{2}-\\d{2} \\d{2}:\\d{2}:\\d{2},\\d{3}";
-  final static public String NAKED_MAIN_REGEX =  "[mM]ain(\\sThread)?";
-  final static public String MAIN_REGEX =  "\\["+NAKED_MAIN_REGEX+"\\]";
+public class ClassicTestConstants {
+  final static public String ISO_REGEX = "\\d{4}-\\d{2}-\\d{2} \\d{2}:\\d{2}:\\d{2},\\d{3}";
+  //pool-1-thread-47
+  final static public String NAKED_MAIN_REGEX = "([mM]ain|pool-\\d-)([Tt]hread)?(-\\d{1,3})?";
+
+
+  final static public String MAIN_REGEX = "\\[" + NAKED_MAIN_REGEX + "\\]";
   final static public String INPUT_PREFIX = "src/test/input/";
-  final static public String JORAN_INPUT_PREFIX = INPUT_PREFIX+"joran/";
+  final static public String JORAN_INPUT_PREFIX = INPUT_PREFIX + "joran/";
+  final static public String GAFFER_INPUT_PREFIX = INPUT_PREFIX + "gaffer/";
+  final static public String OUTPUT_DIR_PREFIX= CoreTestConstants.OUTPUT_DIR_PREFIX;
 }
