@@ -1,3 +1,16 @@
+/**
+ * Logback: the reliable, generic, fast and flexible logging framework.
+ * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ *
+ * This program and the accompanying materials are dual-licensed under
+ * either the terms of the Eclipse Public License v1.0 as published by
+ * the Eclipse Foundation
+ *
+ *   or (per the licensee's choosing)
+ *
+ * under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation.
+ */
 package ch.qos.logback.classic;
 
 import java.io.ByteArrayInputStream;
@@ -9,9 +22,12 @@ import java.io.ObjectOutputStream;
 import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
+import org.slf4j.LoggerFactory;
 
 public class LoggerSerializationTest {
 
+  // force SLF4J initialization for subsequent Logger readResolce ooperaiton
+  org.slf4j.Logger unused = LoggerFactory.getLogger(this.getClass());
   LoggerContext lc;
   Logger logger;
 
@@ -33,7 +49,6 @@ public class LoggerSerializationTest {
   public void tearDown() throws Exception {
     lc = null;
     logger = null;
-    oos.close();
   }
   
   @Test
@@ -47,9 +62,13 @@ public class LoggerSerializationTest {
   private Foo writeAndRead(Foo foo) throws IOException,
       ClassNotFoundException {
     oos.writeObject(foo);
+    oos.flush();
+    oos.close();
     ByteArrayInputStream bis = new ByteArrayInputStream(bos.toByteArray());
     inputStream = new ObjectInputStream(bis);
 
-    return (Foo) inputStream.readObject();
+    Foo fooBack =  (Foo) inputStream.readObject();
+    inputStream.close();
+    return fooBack;
   }
 }
