@@ -21,6 +21,7 @@ import static org.junit.Assert.fail;
 import java.io.IOException;
 
 import org.junit.Test;
+import org.slf4j.MDC;
 import org.slf4j.MarkerFactory;
 
 import ch.qos.logback.classic.Level;
@@ -34,6 +35,8 @@ import ch.qos.logback.core.boolex.JaninoEventEvaluatorBase;
 import ch.qos.logback.core.boolex.Matcher;
 import ch.qos.logback.core.filter.EvaluatorFilter;
 import ch.qos.logback.core.spi.FilterReply;
+import ch.qos.logback.core.testUtil.RandomUtil;
+import ch.qos.logback.core.util.StatusPrinter;
 
 public class JaninoEventEvaluatorTest {
 
@@ -44,6 +47,8 @@ public class JaninoEventEvaluatorTest {
 
   JaninoEventEvaluator jee = new JaninoEventEvaluator();
 
+  int diff = RandomUtil.getPositiveInt();
+  
   public JaninoEventEvaluatorTest() {
     jee.setContext(loggerContext);
 
@@ -65,8 +70,8 @@ public class JaninoEventEvaluatorTest {
     jee.setExpression("message.equals(\"Some message\")");
     jee.start();
 
+    StatusPrinter.print(loggerContext);
     ILoggingEvent event = makeLoggingEvent(null);
-    // System.out.println(event);
     assertTrue(jee.evaluate(event));
   }
 
@@ -76,7 +81,6 @@ public class JaninoEventEvaluatorTest {
     jee.start();
 
     ILoggingEvent event = makeLoggingEvent(null);
-    // System.out.println(event);
     assertTrue(jee.evaluate(event));
   }
 
@@ -99,6 +103,21 @@ public class JaninoEventEvaluatorTest {
     assertTrue(jee.evaluate(event));
   }
 
+
+  @Test
+  public void mdcAsString() throws Exception {
+    String k = "key"+diff;
+    
+    MDC.put("key"+diff, "value"+diff);
+    jee.setExpression("((String) mdc.get(\""+k+"\")).contains(\"alue\")");
+    jee.start();
+    StatusPrinter.printInCaseOfErrorsOrWarnings(loggerContext);
+    
+    LoggingEvent event = makeLoggingEvent(null);
+    assertTrue(jee.evaluate(event));
+    MDC.remove(k);
+  }
+  
   @Test
   public void marker() throws Exception {
     jee.setExpression("marker.contains(\"BLUE\")");
@@ -109,6 +128,7 @@ public class JaninoEventEvaluatorTest {
     assertTrue(jee.evaluate(event));
   }
 
+  
   @Test
   public void withNullMarker_LBCORE_118() throws Exception {
     jee.setExpression("marker.contains(\"BLUE\")");
@@ -241,4 +261,14 @@ public class JaninoEventEvaluatorTest {
     assertTrue(jee.evaluate(event));
   }
 
+
+  @Test
+  public void nullMDC() throws EvaluationException {
+    MDC.clear();
+    jee.setExpression("mdc == null");
+    jee.start();
+
+    LoggingEvent event = makeLoggingEvent(null);
+    assertTrue(jee.evaluate(event));
+  }
 }
