@@ -20,6 +20,8 @@ import org.junit.runners.Suite.SuiteClasses;
 import ch.qos.logback.classic.issue.lbclassic135.lbclassic139.LB139_DeadlockTest;
 
 @RunWith(Suite.class)
-@SuiteClasses(LB139_DeadlockTest.class)
+@SuiteClasses( { LB139_DeadlockTest.class,
+    ch.qos.logback.classic.issue.lbclassic135.lbclassic139.PackageTest.class,
+    ch.qos.logback.classic.issue.lbclassic203.PackageTest.class })
 public class PackageTest {
 }
\ No newline at end of file
