@@ -17,8 +17,8 @@ import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 import org.junit.runners.Suite.SuiteClasses;
 
-
 @RunWith(Suite.class)
-@SuiteClasses( { JoranConfiguratorTest.class, EvaluatorJoranTest.class})
+@SuiteClasses( { JoranConfiguratorTest.class, EvaluatorJoranTest.class,
+    ch.qos.logback.classic.joran.conditional.PackageTest.class })
 public class PackageTest {
 }
\ No newline at end of file
