@@ -19,6 +19,7 @@ import org.junit.runners.Suite.SuiteClasses;
 
 @RunWith(Suite.class)
 @SuiteClasses( { SyslogAppenderTest.class, DilutedSMTPAppenderTest.class,
-    SocketAppenderTest.class, JMSQueueAppenderTest.class, JMSTopicAppenderTest.class })
+    SocketAppenderTest.class, JMSQueueAppenderTest.class, JMSTopicAppenderTest.class,
+        SMTPAppender_GreenTest.class, SMTPAppender_SubethaSMTPTest.class })
 public class PackageTest {
 }
\ No newline at end of file
