@@ -1,11 +1,15 @@
 /**
- * Logback: the generic, reliable, fast and flexible logging framework.
- * 
- * Copyright (C) 2000-2008, QOS.ch
- * 
- * This library is free software, you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation.
+ * Logback: the reliable, generic, fast and flexible logging framework.
+ * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ *
+ * This program and the accompanying materials are dual-licensed under
+ * either the terms of the Eclipse Public License v1.0 as published by
+ * the Eclipse Foundation
+ *
+ *   or (per the licensee's choosing)
+ *
+ * under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation.
  */
 package ch.qos.logback.core;
   
@@ -28,16 +32,6 @@ public interface Appender<E> extends LifeCycle, ContextAware, FilterAttachable<E
    */
   void doAppend(E event) throws LogbackException;
 
-  /**
-   * Set the {@link Layout} for this appender.
-   */
-  public void setLayout(Layout<E> layout);
-
-  /**
-   * Returns this appenders layout.
-   */
-  public Layout<E> getLayout();
-
   /**
    * Set the name of this appender. The name is used by other components to
    * identify this appender.
