@@ -1,11 +1,15 @@
 /**
- * Logback: the generic, reliable, fast and flexible logging framework for Java.
- * 
- * Copyright (C) 2000-2006, QOS.ch
- * 
- * This library is free software, you can redistribute it and/or modify it under
- * the terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation.
+ * Logback: the reliable, generic, fast and flexible logging framework.
+ * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ *
+ * This program and the accompanying materials are dual-licensed under
+ * either the terms of the Eclipse Public License v1.0 as published by
+ * the Eclipse Foundation
+ *
+ *   or (per the licensee's choosing)
+ *
+ * under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation.
  */
 package ch.qos.logback.core;
 
@@ -23,7 +27,8 @@ import org.junit.runners.Suite.SuiteClasses;
   ch.qos.logback.core.appender.PackageTest.class,
   ch.qos.logback.core.spi.PackageTest.class,
   ch.qos.logback.core.rolling.PackageTest.class,
-  ch.qos.logback.core.sift.PackageTest.class})
+  ch.qos.logback.core.sift.PackageTest.class, 
+  ch.qos.logback.core.encoder.PackageTest.class,
+  ch.qos.logback.core.recovery.PackageTest.class})
 public class AllCoreTest {
-
 }
