@@ -17,10 +17,11 @@ import org.junit.runner.RunWith;
 import org.junit.runners.Suite;
 
 @RunWith(Suite.class)
-@Suite.SuiteClasses( { RenamingTest.class, SizeBasedRollingTest.class,
-    TimeBasedRollingTest.class, TimeBasedRollingWithArchiveRemovalTest.class,
+@Suite.SuiteClasses( { RenameUtilTest.class, SizeBasedRollingTest.class,
+    TimeBasedRolling2Test.class, TimeBasedRollingWithArchiveRemovalTest.class,
     MultiThreadedRollingTest.class,
     SizeAndTimeBasedFNATP_Test.class,
+    RollingFileAppenderTest.class,
     ch.qos.logback.core.rolling.helper.PackageTest.class })
 public class PackageTest {
 }
