@@ -19,6 +19,7 @@ import java.util.LinkedList;
 import java.util.List;
 
 import ch.qos.logback.core.Appender;
+import ch.qos.logback.core.CoreConstants;
 import ch.qos.logback.core.sift.AppenderTracker;
 
 /**
@@ -61,7 +62,7 @@ public class AppenderTrackerTImpl implements AppenderTracker<Object> {
   }
 
   synchronized public void stopStaleAppenders(long timestamp) {
-    if (lastCheck + MILLIS_IN_ONE_SECOND > timestamp) {
+    if (lastCheck + CoreConstants.MILLIS_IN_ONE_SECOND > timestamp) {
       return;
     }
     lastCheck = timestamp;
@@ -70,6 +71,20 @@ public class AppenderTrackerTImpl implements AppenderTracker<Object> {
     }
   }
 
+  synchronized public void stopAndRemoveNow(String key) {
+    TEntry found = null;
+    for (TEntry te : entryList) {
+      if (key.equals(te.key)) {
+        found = te;
+        break;
+      }
+    }
+    if (found != null) {
+      entryList.remove(found);
+    }
+
+  }
+
   final private boolean isEntryStale(TEntry entry, long now) {
     return ((entry.timestamp + THRESHOLD) < now);
   }
