@@ -1,3 +1,16 @@
+/**
+ * Logback: the reliable, generic, fast and flexible logging framework.
+ * Copyright (C) 1999-2009, QOS.ch. All rights reserved.
+ *
+ * This program and the accompanying materials are dual-licensed under
+ * either the terms of the Eclipse Public License v1.0 as published by
+ * the Eclipse Foundation
+ *
+ *   or (per the licensee's choosing)
+ *
+ * under the terms of the GNU Lesser General Public License version 2.1
+ * as published by the Free Software Foundation.
+ */
 package ch.qos.logback.core.testUtil;
 
 import java.util.ArrayList;
@@ -34,12 +47,10 @@ public class StringListAppender<E> extends AppenderBase<E> {
     strList.add(res);
   }
 
-  @Override
   public Layout<E> getLayout() {
     return layout;
   }
 
-  @Override
   public void setLayout(Layout<E> layout) {
     this.layout = layout;
   }
